# Generated by Django 4.2.16 on 2025-03-26 20:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('timerboard', '0007_alter_timer_structure'),
    ]

    operations = [
        migrations.AlterField(
            model_name='timer',
            name='timer_type',
            field=models.CharField(choices=[('UNSPECIFIED', 'Not Specified'), ('SHIELD', 'Shield'), ('ARMOR', 'Armor'), ('HULL', 'Hull'), ('FINAL', 'Final'), ('ANCHORING', 'Anchoring'), ('UNANCHORING', 'Unanchoring'), ('ABANDONED', 'Abandoned'), ('THEFT', 'Theft')], default='UNSPECIFIED', max_length=254),
        ),
    ]
