{% extends "admin/change_list.html" %}

{% load i18n %}

{% block object-tools-items %}

{{ block.super }}
    <li>
        <a href="{% url 'teamspeak3:admin_update_ts3_groups' %}" class="btn btn-high">
            {% translate "Update TeamSpeak3 groups" %}
        </a>
    </li>
{% endblock %}
