{% extends "allianceauth/base-bs5.html" %}

{% load django_bootstrap5 %}
{% load i18n %}

{% block page_title %}
    {% blocktranslate with service_name=view.service_name|title %}{{ service_name }} Password Change{% endblocktranslate %}
{% endblock page_title %}

{% block header_nav_brand %}
    {% translate "Available Services" %}
{% endblock header_nav_brand %}

{% block content %}
    <div>
        <h1 class="page-header text-center mb-3">
            {% blocktranslate with service_name=view.service_name|title %}Set {{service_name}} Password{% endblocktranslate %}
        </h1>

        <div class="row justify-content-center">
            <div class="col-md-4 align-self-center">
                <form role="form" action="" method="POST" onsubmit="submitbutton.disabled = true; return true;">
                    {% csrf_token %}
                    {% bootstrap_form form %}
                    <br>
                    <button class="btn btn-lg btn-primary btn-block" name="submitbutton" type="submit">{% translate "Set Password" %}</button>
                </form>
            </div>
        </div>
    </div>
{% endblock content %}
