{% extends "allianceauth/base-bs5.html" %}

{% load i18n %}

{% block page_title %}
    {% translate "Delete Timer" %}
{% endblock page_title %}

{% block header_nav_brand %}
    {% translate "Structure Timers" %}
{% endblock header_nav_brand %}

{% block content %}
    <div>
        {% translate "Delete Timer" as page_header %}
        {% include "framework/header/page-header.html" with title=page_header %}

        {% include "timerboard/index_button.html" %}

        <div class="row justify-content-center">
            <div class="col-md-4">
                <div class="row">
                    <form action="" method="post">
                        {% csrf_token %}

                        <p>{% blocktranslate %}Are you sure you want to delete timer "{{ object }}"?{% endblocktranslate %}</p>

                        <input class="btn btn-danger btn-block" type="submit" value="Confirm">
                    </form>
                </div>
            </div>
        </div>
    </div>
{% endblock content %}
