# Generated by Django 3.2.10 on 2022-04-08 19:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('groupmanagement', '0018_reservedgroupname'),
    ]

    operations = [
        migrations.AddField(
            model_name='authgroup',
            name='restricted',
            field=models.BooleanField(default=False, help_text='Group is restricted. This means that adding or removing users for this group requires a superuser admin.'),
        ),
    ]
