<!-- Start Datatables-js from cdnjs -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/datatables.net/1.13.4/jquery.dataTables.min.js" integrity="sha512-8mDDicdS5IeRnHI+un7skH0RJoB2QMMJmORCHizlxul5jgf9tSWJwpE1eSl/2a9xFQYGOwXLr0Lh5SJPnL4IOw==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/datatables.net-bs/1.13.4/dataTables.bootstrap.min.js" integrity="sha512-D14TIq/nBnZ4mTY+R1t/K0Mm49GvUZ6hgqmOMq0s3zbD2DlBqa8VOFNETlrk2gZcYHA6xhkIesrqmxE2eTNltw==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<!-- End Datatables-js from cdnjs -->
