# Generated by Django 4.2.16 on 2024-10-07 13:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mumble", "0012_mumble_client_info"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="mumbleuser",
            options={
                "permissions": (
                    ("access_mumble", "Can access the Mumble service"),
                    (
                        "view_connection_history",
                        "Can access the connection history of the Mumble service",
                    ),
                )
            },
        ),
        migrations.AlterField(
            model_name="mumbleuser",
            name="release",
            field=models.TextField(
                blank=True,
                editable=False,
                help_text="Client release. For official releases, this equals the version. For snapshots and git compiles, this will be something else.",
                max_length=254,
                null=True,
                verbose_name="Mumble Release",
            ),
        ),
    ]
