{% load static %}
{% load sri %}

<!-- Bootstrap CSS -->
{% if NIGHT_MODE %}
    {% if debug %}
        <!-- In template debug, loading less file instead of CSS -->
        <link rel="stylesheet/less" href="{% static 'allianceauth/css/themes/darkly/darkly.less' %}">
        <script src='https://cdnjs.cloudflare.com/ajax/libs/less.js/4.1.3/less.min.js' integrity='sha512-6gUGqd/zBCrEKbJqPI7iINc61jlOfH5A+SluY15IkNO1o4qP1DEYjQBewTB4l0U4ihXZdupg8Mb77VxqE+37dg==' crossorigin='anonymous' referrerpolicy="no-referrer"></script>
    {% else %}
        {% sri_static 'allianceauth/css/themes/darkly/darkly.min.css' %}
    {% endif %}
{% else %}
    {% if debug %}
        <!-- In template debug, loading less file instead of CSS -->
        <link rel="stylesheet/less" href="{% static 'allianceauth/css/themes/flatly/flatly.less' %}">
        <script src='https://cdnjs.cloudflare.com/ajax/libs/less.js/4.1.3/less.min.js' integrity='sha512-6gUGqd/zBCrEKbJqPI7iINc61jlOfH5A+SluY15IkNO1o4qP1DEYjQBewTB4l0U4ihXZdupg8Mb77VxqE+37dg==' crossorigin='anonymous' referrerpolicy="no-referrer"></script>
    {% else %}
        {% sri_static 'allianceauth/css/themes/flatly/flatly.min.css' %}
    {% endif %}
{% endif %}
<!-- End Bootstrap CSS -->
