{% load i18n %}
{% load navactive %}
{% load auth_notifications %}
<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <meta name="description" content="">
        <meta name="author" content="">
        {% include 'allianceauth/icons.html' %}

        <title>{% block title %}{% block page_title %}{% endblock page_title %} - {{ SITE_NAME }}{% endblock title %}</title>

        {% include 'bundles/bootstrap-css.html' %}
        {% include 'bundles/fontawesome.html' %}
        {% include 'bundles/auth-base-css.html' %}

        {% block extra_css %}{% endblock extra_css %}
    </head>

    <body class="{% if NIGHT_MODE %}template-dark-mode{% else %}template-light-mode{% endif %}">
        <div id="wrapper" class="container">
            <!-- Navigation -->
            {% include 'allianceauth/top-menu.html' %}

            <div class="clearfix{% if user.is_authenticated %} row{% endif %}" id="site-body-wrapper">
                {% if user.is_authenticated %}
                    {% include 'allianceauth/side-menu.html' %}
                {% endif %}

                <div class="{% if user.is_authenticated %}col-sm-10{% else %}col-sm-12{% endif %}">
                    {% include 'allianceauth/messages.html' %}

                    {% block content %}
                    {% endblock content %}
                </div>
            </div>
        </div>

        {% include 'bundles/bootstrap-js.html' %}
        {% include 'bundles/jquery-visibility-js.html' %}

        {% if user.is_authenticated %}
            <script>
                let notificationUPdateSettings = {
                    notificationsListViewUrl: "{% url 'notifications:list' %}",
                    notificationsRefreshTime: "{% notifications_refresh_time %}",
                    userNotificationsCountViewUrl: "{% url 'notifications:user_notifications_count' request.user.pk %}"
                };
            </script>
            {% include 'bundles/refresh-notifications-js.html' %}
        {% endif %}
        {% include 'bundles/evetime-js.html' %}

        {% block extra_javascript %}
        {% endblock extra_javascript %}
        <script>
            {% block extra_script %}
            {% endblock extra_script %}
        </script>
    </body>
</html>
