# Generated by Django 4.2.16 on 2025-01-20 06:16

import allianceauth.crontab.models
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CronOffset',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('minute', models.FloatField(default=allianceauth.crontab.models.random_default, verbose_name='Minute Offset')),
                ('hour', models.FloatField(default=allianceauth.crontab.models.random_default, verbose_name='Hour Offset')),
                ('day_of_month', models.FloatField(default=allianceauth.crontab.models.random_default, verbose_name='Day of Month Offset')),
                ('month_of_year', models.FloatField(default=allianceauth.crontab.models.random_default, verbose_name='Month of Year Offset')),
                ('day_of_week', models.FloatField(default=allianceauth.crontab.models.random_default, verbose_name='Day of Week Offset')),
            ],
            options={
                'verbose_name': 'Cron Offsets',
            },
        ),
    ]
