{% load i18n %}

<div class="card text-center mx-2 mb-3" style="min-width: 18rem; min-height: 18rem;">
    <div class="card-body">
        <h5 class="card-title">{% block title %}{% endblock title %}</h5>

        <p class="card-text">
            {% block active %}
                {% include "services/service_status.html" with username=username %}
            {% endblock active %}
        </p>

        <p class="card-text">
            {% block url %}{% endblock url %}
        </p>

        <p class="card-text">
            {% block user %}
                {% include "services/service_username.html" with username=username %}
            {% endblock user %}
        </p>

        {% block extra %}{% endblock extra %}
    </div>

    <div class="card-footer">
        {% block controls %}{% endblock controls %}
    </div>
</div>
