{% load i18n %}
{% load navactive %}
{% load menu_menu_items %}

<div class="col-auto px-0">
    <div class="collapse collapse-horizontal" tabindex="-1" id="sidebar">
        <div>
            <div class="nav-padding navbar-dark text-bg-dark px-0 d-flex flex-column overflow-hidden vh-100 {% if not user.is_authenticated %}position-relative{% endif %}">
                {% if user.is_authenticated %}
                    <ul id="sidebar-menu" class="navbar-nav flex-column mb-auto overflow-auto pt-2">
                        <li class="d-flex flex-wrap m-2 p-2 pt-0 pb-0 mt-0 mb-0 me-0 pe-0">
                            <i class="nav-link fas fa-tachometer-alt fa-fw align-self-center me-3 {% navactive request 'authentication:dashboard' %}"></i>
                            <a class="nav-link flex-fill align-self-center {% navactive request 'authentication:dashboard' %}" href="{% url 'authentication:dashboard' %}">
                                {% translate "Dashboard" %}
                            </a>
                        </li>

                        {% menu_items %}
                    </ul>

                    {% include 'menu/menu-logo.html' %}
                {% endif %}

                {% include 'menu/menu-user.html' %}
            </div>
        </div>
    </div>
</div>
