# Generated by Django 4.2.15 on 2024-08-14 11:25

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="CustomCSS",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "css",
                    models.TextField(
                        blank=True,
                        help_text="This CSS will be added to the site after the default CSS.",
                        null=True,
                        verbose_name="Your custom CSS",
                    ),
                ),
                ("timestamp", models.DateTimeField(auto_now=True)),
            ],
            options={
                "verbose_name": "Custom CSS",
                "verbose_name_plural": "Custom CSS",
                "default_permissions": (),
            },
        ),
    ]
