# Generated by Django 3.2.10 on 2022-01-05 18:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0015_factions'),
    ]

    operations = [
        migrations.AlterField(
            model_name='evecharacter',
            name='character_name',
            field=models.CharField(db_index=True, max_length=254),
        ),
    ]
