# Generated by Django 1.11.5 on 2017-10-07 06:43

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('services', '0001_squashed_0003_delete_groupcache'),
        ('authentication', '0015_user_profiles'),
    ]

    operations = [
        migrations.CreateModel(
            name='NameFormatConfig',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('service_name', models.CharField(max_length=100)),
                ('default_to_username', models.BooleanField(default=True, help_text='If a user has no main_character, default to using their Auth username instead.')),
                ('format', models.CharField(help_text='For information on constructing name formats, please see the <a href="https://allianceauth.readthedocs.io/en/latest/features/nameformats">name format documentation</a>', max_length=100)),
                ('states', models.ManyToManyField(help_text='States to apply this format to. You should only have one formatter for each state for each service.', to='authentication.State')),
            ],
        ),
    ]
