{% extends "admin/change_list.html" %}

{% load i18n %}

{% block object-tools-items %}

{{ block.super }}
    <li>
        <a href="{% url 'admin:menu_menuitem_add' %}?type={{ folder_type }}" class="addlink">
            {% translate "Add folder" %}
        </a>
    </li>
{% endblock %}
