{% extends "allianceauth/base-bs5.html" %}

{% load i18n %}

{% block page_title %}
    {% translate "Fatlink view" %}
{% endblock page_title %}

{% block header_nav_brand %}
    {% translate "Fleet Activity Tracking" %}
{% endblock header_nav_brand %}

{% block content %}
    <div>
        <h1 class="page-header text-center mb-3">
            {% translate "Edit fatlink" %} "{{ fatlink }}"
        </h1>

        <div class="text-end mb-3">
            <form>
                <button type="submit" onclick="return confirm('{% translate "Are you sure?" %}')" class="btn btn-danger" name="deletefat" value="True">
                    {% translate "Delete fat" %}
                </button>
            </form>
        </div>

        <div class="card card-default">
            <div class="card-header">
                <div class="card-title mb-0">{% translate "Registered characters" %}</div>
            </div>

            <div class="card-body">
                <table class="table table-responsive table-hover">
                    <tr>
                        <th class="text-center">{% translate "User" %}</th>
                        <th class="text-center">{% translate "Character" %}</th>
                        <th class="text-center">{% translate "System" %}</th>
                        <th class="text-center">{% translate "Ship" %}</th>
                        <th class="text-center">{% translate "EVE time" %}</th>
                        <th></th>
                    </tr>

                    {% for fat in registered_fats %}
                        <tr>
                            <td class="text-center">{{ fat.user }}</td>
                            <td class="text-center">{{ fat.character.character_name }}</td>
                            <td class="text-center">
                                {% if fat.station != "No Station" %}
                                    {% translate "Docked in" %}
                                {% endif %}
                                {{ fat.system }}
                            </td>
                            <td class="text-center">{{ fat.shiptype }}</td>
                            <td class="text-center">{{ fat.fatlink.fatdatetime }}</td>
                            <td class="text-center">
                                <form>
                                    <button type="submit" class="btn btn-warning" name="removechar" value="{{ fat.character.character_id }}">
                                        <i class="fa-solid fa-trash-can fa-fw"></i>
                                    </button>
                                </form>
                            </td>
                        </tr>
                    {% endfor %}
                </table>
            </div>
        </div>
    </div>
{% endblock content %}
