# Generated by Django 2.2.12 on 2020-05-26 02:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0011_ids_to_integers'),
    ]

    operations = [
        migrations.AddIndex(
            model_name='eveallianceinfo',
            index=models.Index(fields=['executor_corp_id'], name='eveonline_e_executo_7f3280_idx'),
        ),
        migrations.AddIndex(
            model_name='evecharacter',
            index=models.Index(fields=['corporation_id'], name='eveonline_e_corpora_cb4cd9_idx'),
        ),
        migrations.AddIndex(
            model_name='evecharacter',
            index=models.Index(fields=['alliance_id'], name='eveonline_e_allianc_39ee2a_idx'),
        ),
        migrations.AddIndex(
            model_name='evecharacter',
            index=models.Index(fields=['corporation_name'], name='eveonline_e_corpora_893c60_idx'),
        ),
        migrations.AddIndex(
            model_name='evecharacter',
            index=models.Index(fields=['alliance_name'], name='eveonline_e_allianc_63fd98_idx'),
        ),
    ]
