# Generated by Django 4.0.2 on 2022-02-26 03:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('authentication', '0019_merge_20211026_0919'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='language',
            field=models.CharField(blank=True, choices=[('en', 'English'), ('de', 'German'), ('es', 'Spanish'), ('zh-hans', 'Chinese Simplified'), ('ru', 'Russian'), ('ko', 'Korean'), ('fr', 'French'), ('ja', 'Japanese'), ('it', 'Italian')], default='', max_length=10, verbose_name='Language'),
        ),
        migrations.AddField(
            model_name='userprofile',
            name='night_mode',
            field=models.BooleanField(blank=True, null=True, verbose_name='Night Mode'),
        ),
    ]
