# Generated by Django 4.2.17 on 2025-01-06 17:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("timerboard", "0006_alter_timer_objective_alter_timer_structure_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="timer",
            name="structure",
            field=models.CharField(
                choices=[
                    ("POCO", "POCO"),
                    ("Orbital Skyhook", "Orbital Skyhook"),
                    ("I-HUB", "Sovereignty Hub"),
                    ("TCU", "TCU"),
                    ("POS[S]", "POS [S]"),
                    ("POS[M]", "POS [M]"),
                    ("POS[L]", "POS [L]"),
                    ("Astrahus", "Astrahus"),
                    ("Fortizar", "Fortizar"),
                    ("Keepstar", "Keepstar"),
                    ("Raitaru", "Raitaru"),
                    ("Azbel", "Azbel"),
                    ("Sotiyo", "Sotiyo"),
                    ("Athanor", "Athanor"),
                    ("Tatara", "Tatara"),
                    ("Pharolux Cyno Beacon", "Cyno Beacon"),
                    ("Tenebrex Cyno Jammer", "Cyno Jammer"),
                    ("Ansiblex Jump Gate", "Ansiblex Jump Gate"),
                    ("Mercenary Den", "Mercenary Den"),
                    ("Moon Mining Cycle", "Moon Mining Cycle"),
                    ("Metenox Moon Drill", "Metenox Moon Drill"),
                    ("Other", "Other"),
                ],
                default="Other",
                max_length=254,
            ),
        ),
    ]
