from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class EveonlineConfig(AppConfig):
    name = 'allianceauth.eveonline'
    label = 'eveonline'
    verbose_name = _('EVE Online')
