{% load i18n %}
{% load navactive %}
{% load menu_items %}

<div class="col-sm-2 auth-side-navbar" role="navigation">
    <div class="collapse navbar-collapse auth-menus-collapse auth-side-navbar-collapse">
        <ul class="nav nav-pills nav-stacked gray-icon-color" id="side-menu">
            <li>
                <a class="{% navactive request 'authentication:dashboard' %}" href="{% url 'authentication:dashboard' %}">
                    <i class="fa-solid fa-gauge-high fa-fw"></i> {% translate "Dashboard" %}
                </a>
            </li>

            {% menu_items %}
        </ul>
    </div>
</div>
