# Generated by Django 2.0.2 on 2018-02-28 18:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fleetactivitytracking', '0004_make_strings_more_stringy'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='fatlink',
            name='name',
        ),
        migrations.AlterField(
            model_name='fatlink',
            name='fleet',
            field=models.CharField(max_length=254),
        ),
    ]
