# Generated by Django 4.2.16 on 2024-12-11 02:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('analytics', '0009_remove_analyticstokens_ignore_paths_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='analyticsidentifier',
            options={'verbose_name': 'Analytics Identifier'},
        ),
    ]
