# Generated by Django 2.0.8 on 2018-12-07 08:56

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('groupmanagement', '0010_authgroup_states'),
    ]

    operations = [
        migrations.AddField(
            model_name='requestlog',
            name='date',
            field=models.DateTimeField(default=datetime.datetime(2018, 12, 7, 8, 56, 33, 846342)),
        ),
    ]
